@@ -4,13 +4,10 @@ from github_custom_actions import ActionBase
 class MyAction(ActionBase):
     def main(self):
         self.outputs["runner-os"] = self.env.runner_os
-        self.summary.text += (
-            self.render(
-                "### {{ inputs['my-input'] }}.\n"
-                "Have a nice day!"
-            )
+        self.summary.text += self.render(
+            "### {{ inputs['my-input'] }}.\nHave a nice day!",
         )
 
 
 if __name__ == "__main__":
-    MyAction().run()
\ No newline at end of file
+    MyAction().run()
