@@ -1,14 +1,14 @@
 import typing
-from typing import Dict, Any
+from typing import Any, Dict, Type
 
 
 class AttrDictVars:
     """Common base class for accessing variables as attributes or dict."""
 
-    _type_hints_cache: Dict[str, Dict[str, Any]] = {}
+    _type_hints_cache: Dict[str, Dict[str, Type[Any]]] = {}
 
     @classmethod
-    def _get_type_hints(cls) -> Dict[str, Any]:
+    def get_type_hints(cls) -> Dict[str, Any]:
         class_name = cls.__name__
         if class_name not in cls._type_hints_cache:
             cls._type_hints_cache[class_name] = typing.get_type_hints(cls)
